==> unidecode_0.04.14.orig.tar.gz: Unidecode-0.04.14/unidecode/x079.py <==
data = (
'Tani ',    # 0x00
'Jiao ',    # 0x01
'[?] ',    # 0x02
'Zhang ',    # 0x03
'Qiao ',    # 0x04
'Dun ',    # 0x05
'Xian ',    # 0x06
'Yu ',    # 0x07
'Zhui ',    # 0x08
'He ',    # 0x09
'Huo ',    # 0x0a
'Zhai ',    # 0x0b
'Lei ',    # 0x0c
'Ke ',    # 0x0d
'Chu ',    # 0x0e
'Ji ',    # 0x0f
'Que ',    # 0x10
'Dang ',    # 0x11
'Yi ',    # 0x12
'Jiang ',    # 0x13
'Pi ',    # 0x14
'Pi ',    # 0x15
'Yu ',    # 0x16
'Pin ',    # 0x17
'Qi ',    # 0x18
'Ai ',    # 0x19
'Kai ',    # 0x1a
'Jian ',    # 0x1b
'Yu ',    # 0x1c
'Ruan ',    # 0x1d
'Meng ',    # 0x1e
'Pao ',    # 0x1f
'Ci ',    # 0x20
'[?] ',    # 0x21
'[?] ',    # 0x22
'Mie ',    # 0x23
'Ca ',    # 0x24
'Xian ',    # 0x25
'Kuang ',    # 0x26
'Lei ',    # 0x27
'Lei ',    # 0x28
'Zhi ',    # 0x29
'Li ',    # 0x2a
'Li ',    # 0x2b
'Fan ',    # 0x2c
'Que ',    # 0x2d
'Pao ',    # 0x2e
'Ying ',    # 0x2f
'Li ',    # 0x30
'Long ',    # 0x31
'Long ',    # 0x32
'Mo ',    # 0x33
'Bo ',    # 0x34
'Shuang ',    # 0x35
'Guan ',    # 0x36
'Lan ',    # 0x37
'Zan ',    # 0x38
'Yan ',    # 0x39
'Shi ',    # 0x3a
'Shi ',    # 0x3b
'Li ',    # 0x3c
'Reng ',    # 0x3d
'She ',    # 0x3e
'Yue ',    # 0x3f
'Si ',    # 0x40
'Qi ',    # 0x41
'Ta ',    # 0x42
'Ma ',    # 0x43
'Xie ',    # 0x44
'Xian ',    # 0x45
'Xian ',    # 0x46
'Zhi ',    # 0x47
'Qi ',    # 0x48
'Zhi ',    # 0x49
'Beng ',    # 0x4a
'Dui ',    # 0x4b
'Zhong ',    # 0x4c
'[?] ',    # 0x4d
'Yi ',    # 0x4e
'Shi ',    # 0x4f
'You ',    # 0x50
'Zhi ',    # 0x51
'Tiao ',    # 0x52
'Fu ',    # 0x53
'Fu ',    # 0x54
'Mi ',    # 0x55
'Zu ',    # 0x56
'Zhi ',    # 0x57
'Suan ',    # 0x58
'Mei ',    # 0x59
'Zuo ',    # 0x5a
'Qu ',    # 0x5b
'Hu ',    # 0x5c
'Zhu ',    # 0x5d
'Shen ',    # 0x5e
'Sui ',    # 0x5f
'Ci ',    # 0x60
'Chai ',    # 0x61
'Mi ',    # 0x62
'Lu ',    # 0x63
'Yu ',    # 0x64
'Xiang ',    # 0x65
'Wu ',    # 0x66
'Tiao ',    # 0x67
'Piao ',    # 0x68
'Zhu ',    # 0x69
'Gui ',    # 0x6a
'Xia ',    # 0x6b
'Zhi ',    # 0x6c
'Ji ',    # 0x6d
'Gao ',    # 0x6e
'Zhen ',    # 0x6f
'Gao ',    # 0x70
'Shui ',    # 0x71
'Jin ',    # 0x72
'Chen ',    # 0x73
'Gai ',    # 0x74
'Kun ',    # 0x75
'Di ',    # 0x76
'Dao ',    # 0x77
'Huo ',    # 0x78
'Tao ',    # 0x79
'Qi ',    # 0x7a
'Gu ',    # 0x7b
'Guan ',    # 0x7c
'Zui ',    # 0x7d
'Ling ',    # 0x7e
'Lu ',    # 0x7f
'Bing ',    # 0x80
'Jin ',    # 0x81
'Dao ',    # 0x82
'Zhi ',    # 0x83
'Lu ',    # 0x84
'Shan ',    # 0x85
'Bei ',    # 0x86
'Zhe ',    # 0x87
'Hui ',    # 0x88
'You ',    # 0x89
'Xi ',    # 0x8a
'Yin ',    # 0x8b
'Zi ',    # 0x8c
'Huo ',    # 0x8d
'Zhen ',    # 0x8e
'Fu ',    # 0x8f
'Yuan ',    # 0x90
'Wu ',    # 0x91
'Xian ',    # 0x92
'Yang ',    # 0x93
'Ti ',    # 0x94
'Yi ',    # 0x95
'Mei ',    # 0x96
'Si ',    # 0x97
'Di ',    # 0x98
'[?] ',    # 0x99
'Zhuo ',    # 0x9a
'Zhen ',    # 0x9b
'Yong ',    # 0x9c
'Ji ',    # 0x9d
'Gao ',    # 0x9e
'Tang ',    # 0x9f
'Si ',    # 0xa0
'Ma ',    # 0xa1
'Ta ',    # 0xa2
'[?] ',    # 0xa3
'Xuan ',    # 0xa4
'Qi ',    # 0xa5
'Yu ',    # 0xa6
'Xi ',    # 0xa7
'Ji ',    # 0xa8
'Si ',    # 0xa9
'Chan ',    # 0xaa
'Tan ',    # 0xab
'Kuai ',    # 0xac
'Sui ',    # 0xad
'Li ',    # 0xae
'Nong ',    # 0xaf
'Ni ',    # 0xb0
'Dao ',    # 0xb1
'Li ',    # 0xb2
'Rang ',    # 0xb3
'Yue ',    # 0xb4
'Ti ',    # 0xb5
'Zan ',    # 0xb6
'Lei ',    # 0xb7
'Rou ',    # 0xb8
'Yu ',    # 0xb9
'Yu ',    # 0xba
'Chi ',    # 0xbb
'Xie ',    # 0xbc
'Qin ',    # 0xbd
'He ',    # 0xbe
'Tu ',    # 0xbf
'Xiu ',    # 0xc0
'Si ',    # 0xc1
'Ren ',    # 0xc2
'Tu ',    # 0xc3
'Zi ',    # 0xc4
'Cha ',    # 0xc5
'Gan ',    # 0xc6
'Yi ',    # 0xc7
'Xian ',    # 0xc8
'Bing ',    # 0xc9
'Nian ',    # 0xca
'Qiu ',    # 0xcb
'Qiu ',    # 0xcc
'Chong ',    # 0xcd
'Fen ',    # 0xce
'Hao ',    # 0xcf
'Yun ',    # 0xd0
'Ke ',    # 0xd1
'Miao ',    # 0xd2
'Zhi ',    # 0xd3
'Geng ',    # 0xd4
'Bi ',    # 0xd5
'Zhi ',    # 0xd6
'Yu ',    # 0xd7
'Mi ',    # 0xd8
'Ku ',    # 0xd9
'Ban ',    # 0xda
'Pi ',    # 0xdb
'Ni ',    # 0xdc
'Li ',    # 0xdd
'You ',    # 0xde
'Zu ',    # 0xdf
'Pi ',    # 0xe0
'Ba ',    # 0xe1
'Ling ',    # 0xe2
'Mo ',    # 0xe3
'Cheng ',    # 0xe4
'Nian ',    # 0xe5
'Qin ',    # 0xe6
'Yang ',    # 0xe7
'Zuo ',    # 0xe8
'Zhi ',    # 0xe9
'Zhi ',    # 0xea
'Shu ',    # 0xeb
'Ju ',    # 0xec
'Zi ',    # 0xed
'Huo ',    # 0xee
'Ji ',    # 0xef
'Cheng ',    # 0xf0
'Tong ',    # 0xf1
'Zhi ',    # 0xf2
'Huo ',    # 0xf3
'He ',    # 0xf4
'Yin ',    # 0xf5
'Zi ',    # 0xf6
'Zhi ',    # 0xf7
'Jie ',    # 0xf8
'Ren ',    # 0xf9
'Du ',    # 0xfa
'Yi ',    # 0xfb
'Zhu ',    # 0xfc
'Hui ',    # 0xfd
'Nong ',    # 0xfe
'Fu ',    # 0xff
)

==> unidecode_1.2.0.orig.tar.gz: Unidecode-1.2.0/unidecode/x079.py <==
data = (
'Tani ',    # 0x00
'Jiao ',    # 0x01
None,    # 0x02
'Zhang ',    # 0x03
'Qiao ',    # 0x04
'Dun ',    # 0x05
'Xian ',    # 0x06
'Yu ',    # 0x07
'Zhui ',    # 0x08
'He ',    # 0x09
'Huo ',    # 0x0a
'Zhai ',    # 0x0b
'Lei ',    # 0x0c
'Ke ',    # 0x0d
'Chu ',    # 0x0e
'Ji ',    # 0x0f
'Que ',    # 0x10
'Dang ',    # 0x11
'Yi ',    # 0x12
'Jiang ',    # 0x13
'Pi ',    # 0x14
'Pi ',    # 0x15
'Yu ',    # 0x16
'Pin ',    # 0x17
'Qi ',    # 0x18
'Ai ',    # 0x19
'Kai ',    # 0x1a
'Jian ',    # 0x1b
'Yu ',    # 0x1c
'Ruan ',    # 0x1d
'Meng ',    # 0x1e
'Pao ',    # 0x1f
'Ci ',    # 0x20
None,    # 0x21
None,    # 0x22
'Mie ',    # 0x23
'Ca ',    # 0x24
'Xian ',    # 0x25
'Kuang ',    # 0x26
'Lei ',    # 0x27
'Lei ',    # 0x28
'Zhi ',    # 0x29
'Li ',    # 0x2a
'Li ',    # 0x2b
'Fan ',    # 0x2c
'Que ',    # 0x2d
'Pao ',    # 0x2e
'Ying ',    # 0x2f
'Li ',    # 0x30
'Long ',    # 0x31
'Long ',    # 0x32
'Mo ',    # 0x33
'Bo ',    # 0x34
'Shuang ',    # 0x35
'Guan ',    # 0x36
'Lan ',    # 0x37
'Zan ',    # 0x38
'Yan ',    # 0x39
'Shi ',    # 0x3a
'Shi ',    # 0x3b
'Li ',    # 0x3c
'Reng ',    # 0x3d
'She ',    # 0x3e
'Yue ',    # 0x3f
'Si ',    # 0x40
'Qi ',    # 0x41
'Ta ',    # 0x42
'Ma ',    # 0x43
'Xie ',    # 0x44
'Xian ',    # 0x45
'Xian ',    # 0x46
'Zhi ',    # 0x47
'Qi ',    # 0x48
'Zhi ',    # 0x49
'Beng ',    # 0x4a
'Dui ',    # 0x4b
'Zhong ',    # 0x4c
None,    # 0x4d
'Yi ',    # 0x4e
'Shi ',    # 0x4f
'You ',    # 0x50
'Zhi ',    # 0x51
'Tiao ',    # 0x52
'Fu ',    # 0x53
'Fu ',    # 0x54
'Mi ',    # 0x55
'Zu ',    # 0x56
'Zhi ',    # 0x57
'Suan ',    # 0x58
'Mei ',    # 0x59
'Zuo ',    # 0x5a
'Qu ',    # 0x5b
'Hu ',    # 0x5c
'Zhu ',    # 0x5d
'Shen ',    # 0x5e
'Sui ',    # 0x5f
'Ci ',    # 0x60
'Chai ',    # 0x61
'Mi ',    # 0x62
'Lu ',    # 0x63
'Yu ',    # 0x64
'Xiang ',    # 0x65
'Wu ',    # 0x66
'Tiao ',    # 0x67
'Piao ',    # 0x68
'Zhu ',    # 0x69
'Gui ',    # 0x6a
'Xia ',    # 0x6b
'Zhi ',    # 0x6c
'Ji ',    # 0x6d
'Gao ',    # 0x6e
'Zhen ',    # 0x6f
'Gao ',    # 0x70
'Shui ',    # 0x71
'Jin ',    # 0x72
'Chen ',    # 0x73
'Gai ',    # 0x74
'Kun ',    # 0x75
'Di ',    # 0x76
'Dao ',    # 0x77
'Huo ',    # 0x78
'Tao ',    # 0x79
'Qi ',    # 0x7a
'Gu ',    # 0x7b
'Guan ',    # 0x7c
'Zui ',    # 0x7d
'Ling ',    # 0x7e
'Lu ',    # 0x7f
'Bing ',    # 0x80
'Jin ',    # 0x81
'Dao ',    # 0x82
'Zhi ',    # 0x83
'Lu ',    # 0x84
'Shan ',    # 0x85
'Bei ',    # 0x86
'Zhe ',    # 0x87
'Hui ',    # 0x88
'You ',    # 0x89
'Xi ',    # 0x8a
'Yin ',    # 0x8b
'Zi ',    # 0x8c
'Huo ',    # 0x8d
'Zhen ',    # 0x8e
'Fu ',    # 0x8f
'Yuan ',    # 0x90
'Wu ',    # 0x91
'Xian ',    # 0x92
'Yang ',    # 0x93
'Ti ',    # 0x94
'Yi ',    # 0x95
'Mei ',    # 0x96
'Si ',    # 0x97
'Di ',    # 0x98
None,    # 0x99
'Zhuo ',    # 0x9a
'Zhen ',    # 0x9b
'Yong ',    # 0x9c
'Ji ',    # 0x9d
'Gao ',    # 0x9e
'Tang ',    # 0x9f
'Si ',    # 0xa0
'Ma ',    # 0xa1
'Ta ',    # 0xa2
None,    # 0xa3
'Xuan ',    # 0xa4
'Qi ',    # 0xa5
'Yu ',    # 0xa6
'Xi ',    # 0xa7
'Ji ',    # 0xa8
'Si ',    # 0xa9
'Chan ',    # 0xaa
'Tan ',    # 0xab
'Kuai ',    # 0xac
'Sui ',    # 0xad
'Li ',    # 0xae
'Nong ',    # 0xaf
'Ni ',    # 0xb0
'Dao ',    # 0xb1
'Li ',    # 0xb2
'Rang ',    # 0xb3
'Yue ',    # 0xb4
'Ti ',    # 0xb5
'Zan ',    # 0xb6
'Lei ',    # 0xb7
'Rou ',    # 0xb8
'Yu ',    # 0xb9
'Yu ',    # 0xba
'Chi ',    # 0xbb
'Xie ',    # 0xbc
'Qin ',    # 0xbd
'He ',    # 0xbe
'Tu ',    # 0xbf
'Xiu ',    # 0xc0
'Si ',    # 0xc1
'Ren ',    # 0xc2
'Tu ',    # 0xc3
'Zi ',    # 0xc4
'Cha ',    # 0xc5
'Gan ',    # 0xc6
'Yi ',    # 0xc7
'Xian ',    # 0xc8
'Bing ',    # 0xc9
'Nian ',    # 0xca
'Qiu ',    # 0xcb
'Qiu ',    # 0xcc
'Chong ',    # 0xcd
'Fen ',    # 0xce
'Hao ',    # 0xcf
'Yun ',    # 0xd0
'Ke ',    # 0xd1
'Miao ',    # 0xd2
'Zhi ',    # 0xd3
'Geng ',    # 0xd4
'Bi ',    # 0xd5
'Zhi ',    # 0xd6
'Yu ',    # 0xd7
'Mi ',    # 0xd8
'Ku ',    # 0xd9
'Ban ',    # 0xda
'Pi ',    # 0xdb
'Ni ',    # 0xdc
'Li ',    # 0xdd
'You ',    # 0xde
'Zu ',    # 0xdf
'Pi ',    # 0xe0
'Ba ',    # 0xe1
'Ling ',    # 0xe2
'Mo ',    # 0xe3
'Cheng ',    # 0xe4
'Nian ',    # 0xe5
'Qin ',    # 0xe6
'Yang ',    # 0xe7
'Zuo ',    # 0xe8
'Zhi ',    # 0xe9
'Zhi ',    # 0xea
'Shu ',    # 0xeb
'Ju ',    # 0xec
'Zi ',    # 0xed
'Huo ',    # 0xee
'Ji ',    # 0xef
'Cheng ',    # 0xf0
'Tong ',    # 0xf1
'Zhi ',    # 0xf2
'Huo ',    # 0xf3
'He ',    # 0xf4
'Yin ',    # 0xf5
'Zi ',    # 0xf6
'Zhi ',    # 0xf7
'Jie ',    # 0xf8
'Ren ',    # 0xf9
'Du ',    # 0xfa
'Yi ',    # 0xfb
'Zhu ',    # 0xfc
'Hui ',    # 0xfd
'Nong ',    # 0xfe
'Fu ',    # 0xff
)
